==> texinfo_7.1.1.orig.tar.xz: texinfo-7.1.1/tp/t/results/xml_tests/top_node_no_section.pl <==
use vars qw(%result_texis %result_texts %result_trees %result_errors 
   %result_indices %result_sectioning %result_nodes %result_menus
   %result_floats %result_converted %result_converted_errors 
   %result_elements %result_directions_text %result_indices_sort_strings);

use utf8;

$result_trees{'top_node_no_section'} = {
  'contents' => [
    {
      'type' => 'before_node_section'
    },
    {
      'args' => [
        {
          'contents' => [
            {
              'text' => 'Top'
            }
          ],
          'info' => {
            'spaces_after_argument' => {
              'text' => '
'
            }
          },
          'type' => 'line_arg'
        }
      ],
      'cmdname' => 'node',
      'extra' => {
        'normalized' => 'Top'
      },
      'info' => {
        'spaces_before_argument' => {
          'text' => ' '
        }
      },
      'source_info' => {
        'file_name' => '',
        'line_nr' => 1,
        'macro' => ''
      }
    }
  ],
  'type' => 'document_root'
};

$result_texis{'top_node_no_section'} = '@node Top
';


$result_texts{'top_node_no_section'} = '';

$result_nodes{'top_node_no_section'} = {
  'cmdname' => 'node',
  'extra' => {
    'normalized' => 'Top'
  }
};

$result_menus{'top_node_no_section'} = {
  'cmdname' => 'node',
  'extra' => {
    'normalized' => 'Top'
  }
};

$result_errors{'top_node_no_section'} = [];


$result_floats{'top_node_no_section'} = {};



$result_converted{'xml'}->{'top_node_no_section'} = '<node name="Top" spaces=" "><nodename>Top</nodename></node>
';

1;

==> texinfo-7.2.tar.xz: texinfo-7.2/tp/t/results/xml_tests/top_node_no_section.pl <==
use vars qw(%result_texis %result_texts %result_trees %result_errors 
   %result_indices %result_sectioning %result_nodes %result_menus
   %result_floats %result_converted %result_converted_errors 
   %result_elements %result_directions_text %result_indices_sort_strings);

use utf8;

$result_trees{'top_node_no_section'} = {
  'contents' => [
    {
      'type' => 'before_node_section'
    },
    {
      'args' => [
        {
          'contents' => [
            {
              'text' => 'Top'
            }
          ],
          'info' => {
            'spaces_after_argument' => {
              'text' => '
'
            }
          },
          'type' => 'line_arg'
        }
      ],
      'cmdname' => 'node',
      'extra' => {
        'is_target' => 1,
        'normalized' => 'Top'
      },
      'info' => {
        'spaces_before_argument' => {
          'text' => ' '
        }
      },
      'source_info' => {
        'line_nr' => 1
      }
    }
  ],
  'type' => 'document_root'
};

$result_texis{'top_node_no_section'} = '@node Top
';


$result_texts{'top_node_no_section'} = '';

$result_nodes{'top_node_no_section'} = [
  {
    'cmdname' => 'node',
    'extra' => {
      'normalized' => 'Top'
    }
  }
];

$result_menus{'top_node_no_section'} = [
  {
    'extra' => {
      'normalized' => 'Top'
    }
  }
];

$result_errors{'top_node_no_section'} = [];


$result_floats{'top_node_no_section'} = {};



$result_converted{'xml'}->{'top_node_no_section'} = '<node name="Top" spaces=" "><nodename>Top</nodename></node>
';

1;
